summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/connectionhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/liboscar/connectionhandler.h')
-rw-r--r--kopete/protocols/oscar/liboscar/connectionhandler.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/protocols/oscar/liboscar/connectionhandler.h b/kopete/protocols/oscar/liboscar/connectionhandler.h
index 6094cab3..e8c50b12 100644
--- a/kopete/protocols/oscar/liboscar/connectionhandler.h
+++ b/kopete/protocols/oscar/liboscar/connectionhandler.h
@@ -20,13 +20,13 @@
#define CONNECTIONHANDLER_H
#include "oscartypes.h"
-#include <qstring.h>
-#include <qpair.h>
+#include <tqstring.h>
+#include <tqpair.h>
class Connection;
-typedef QPair<Oscar::WORD, QString> ConnectionRoomInfo;
+typedef QPair<Oscar::WORD, TQString> ConnectionRoomInfo;
/**
@author Kopete Developers
@@ -84,7 +84,7 @@ public:
* @param exchange the exchange the chat room is in
* @param room the name of the chat room
*/
- void addChatInfoForConnection( Connection* c, Oscar::WORD exchange, const QString& room );
+ void addChatInfoForConnection( Connection* c, Oscar::WORD exchange, const TQString& room );
/**
* Get the connection for a particular room name and exchange number.
@@ -92,15 +92,15 @@ public:
* @param room the name of the chat room to find a connection for
* @return a Connection for the chat room or 0L if no connection for that room
*/
- Connection* connectionForChatRoom( Oscar::WORD exchange, const QString& room );
+ Connection* connectionForChatRoom( Oscar::WORD exchange, const TQString& room );
/**
* Get the room name for the chat room based the connection
* @return The name of the chat room that this connection is connected to
* If the connection passed in by @p c is not a chat room connection then
* QString::null is returned.
*/
- QString chatRoomForConnection( Connection* c );
+ TQString chatRoomForConnection( Connection* c );
/**
* Get the exchange number for the chat room based on the connection
@@ -92,15 +92,15 @@ public:
* @return The name of the chat room that this connection is connected to
* If the connection passed in by @p c is not a chat room connection then
- * QString::null is returned.
+ * TQString::null is returned.
*/